@@ -75,6 +75,12 @@ AsValidatorIssueTag as_validator_issue_tag_list[] =  {
 	  N_("Enumerations must only have list items (<li/>) as children.")
 	},
 
+	{ "description-enum-group-translated",
+	  AS_ISSUE_SEVERITY_ERROR,
+	  N_("The enumeration must not be translated as a whole. "
+	     "In MetaInfo files, translate individual items (<li/> elements) instead.")
+	},
+
 	{ "description-first-para-too-short",
 	  AS_ISSUE_SEVERITY_INFO,
 	  N_("The first `description/p` paragraph of this component might be too short (< 80 characters). "
@@ -520,7 +526,7 @@ AsValidatorIssueTag as_validator_issue_tag_list[] =  {
 
 	{ "summary-too-long",
 	  AS_ISSUE_SEVERITY_WARNING,
-	  N_("The summary text is very long, and will likely not be displayed properly everywhere.")
+	  N_("The summary text is very long, and will likely not be displayed properly everywhere. It should be <= 90 characters.")
 	},
 
 	{ "icon-stock-cached-has-url",
@@ -603,7 +609,7 @@ AsValidatorIssueTag as_validator_issue_tag_list[] =  {
 	},
 
 	{ "developer-id-missing",
-	  AS_ISSUE_SEVERITY_WARNING,
+	  AS_ISSUE_SEVERITY_INFO,
 	  /* TRANSLATORS: Please do not translate AppStream tag and property names (in backticks). */
 	  N_("The `developer` element is missing an `id` property, containing a unique string ID for the developer. "
 	     "Consider adding a unique ID."),
@@ -944,7 +950,13 @@ AsValidatorIssueTag as_validator_issue_tag_list[] =  {
 	{ "release-time-missing",
 	  AS_ISSUE_SEVERITY_ERROR,
 	  /* TRANSLATORS: Please do not translate AppStream tag and property names (in backticks). */
-	  N_("The release is missing either the `date` (preferred) or the `timestamp` property."),
+	  N_("The release entry is missing either the `date` (preferred) or the `timestamp` property."),
+	},
+
+	{ "release-time-missing-for-snapshot",
+	  AS_ISSUE_SEVERITY_INFO,
+	  /* TRANSLATORS: Please do not translate AppStream tag and property names (in backticks). */
+	  N_("The release entry is missing the `date` property. Ensure to add it before publishing the snapshot release."),
 	},
 
 	{ "release-timestamp-invalid",
@@ -1127,11 +1139,22 @@ AsValidatorIssueTag as_validator_issue_tag_list[] =  {
 	  N_("The value of this color scheme preference is not valid."),
 	},
 
+	{ "branding-color-scheme-wrong-property",
+	  AS_ISSUE_SEVERITY_ERROR,
+	  /* TRANSLATORS: Please do not translate AppStream tag and property names (in backticks). */
+	  N_("The name of the color scheme property is wrong. It should be `scheme_preference`."),
+	},
+
 	{ "branding-color-invalid",
 	  AS_ISSUE_SEVERITY_ERROR,
 	  N_("This color is not a valid HTML color code."),
 	},
 
+	{ "branding-color-duplicated",
+	  AS_ISSUE_SEVERITY_ERROR,
+	  N_("A color for this type/scheme combination was already set. Colors must be unique per type/scheme."),
+	},
+
 	{ "reference-doi-invalid",
 	  AS_ISSUE_SEVERITY_WARNING,
 	  N_("The given DOI (Digital Object Identifier) for this reference item is not valid."),
